@@ -4,7 +4,7 @@
  *
  *  Copyright (C) 2000-2001  Qualcomm Incorporated
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2009  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -41,9 +41,9 @@
 #include <sys/ioctl.h>
 #include <sys/socket.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
-#include <bluetooth/hci_lib.h>
+#include "bluetooth.h"
+#include "hci.h"
+#include "hci_lib.h"
 
 #ifndef MIN
 #define MIN(x, y) ((x) < (y) ? (x) : (y))
@@ -510,6 +510,7 @@ char *hci_cmdtostr(unsigned int cmd)
 
 char *hci_commandstostr(uint8_t *commands, char *pref, int width)
 {
+	unsigned int maxwidth = width - 3;
 	hci_map *m;
 	char *off, *ptr, *str;
 	int size = 10;
@@ -537,7 +538,7 @@ char *hci_commandstostr(uint8_t *commands, char *pref, int width)
 
 	while (m->str) {
 		if (commands[m->val / 8] & (1 << (m->val % 8))) {
-			if (strlen(off) + strlen(m->str) > width - 3) {
+			if (strlen(off) + strlen(m->str) > maxwidth) {
 				ptr += sprintf(ptr, "\n%s", pref ? pref : "");
 				off = ptr;
 			}
@@ -556,6 +557,7 @@ static hci_map ver_map[] = {
 	{ "1.2",	0x02 },
 	{ "2.0",	0x03 },
 	{ "2.1",	0x04 },
+	{ "3.0",	0x05 },
 	{ NULL }
 };
 
@@ -670,6 +672,7 @@ static hci_map lmp_features_map[8][9] = {
 
 char *lmp_featurestostr(uint8_t *features, char *pref, int width)
 {
+	unsigned int maxwidth = width - 1;
 	char *off, *ptr, *str;
 	int i, size = 10;
 
@@ -699,7 +702,7 @@ char *lmp_featurestostr(uint8_t *features, char *pref, int width)
 
 		while (m->str) {
 			if (m->val & features[i]) {
-				if (strlen(off) + strlen(m->str) > width - 1) {
+				if (strlen(off) + strlen(m->str) > maxwidth) {
 					ptr += sprintf(ptr, "\n%s", pref ? pref : "");
 					off = ptr;
 				}
@@ -988,12 +991,12 @@ int hci_send_req(int dd, struct hci_request *r, int to)
 	unsigned char buf[HCI_MAX_EVENT_SIZE], *ptr;
 	uint16_t opcode = htobs(cmd_opcode_pack(r->ogf, r->ocf));
 	struct hci_filter nf, of;
-	socklen_t len;
+	socklen_t olen;
 	hci_event_hdr *hdr;
 	int err, try;
 
-	len = sizeof(of);
-	if (getsockopt(dd, SOL_HCI, HCI_FILTER, &of, &len) < 0)
+	olen = sizeof(of);
+	if (getsockopt(dd, SOL_HCI, HCI_FILTER, &of, &olen) < 0)
 		return -1;
 
 	hci_filter_clear(&nf);
@@ -1014,6 +1017,7 @@ int hci_send_req(int dd, struct hci_request *r, int to)
 		evt_cmd_status *cs;
 		evt_remote_name_req_complete *rn;
 		remote_name_req_cp *cp;
+		int len;
 
 		if (to) {
 			struct pollfd p;
@@ -1305,7 +1309,7 @@ int hci_read_remote_version(int dd, uint16_t handle, struct hci_version *ver, in
 		return -1;
 	}
 
-	ver->err = btohs(rp.err);
+	ver->manufacturer = btohs(rp.manufacturer);
 	ver->lmp_ver      = rp.lmp_ver;
 	ver->lmp_subver   = btohs(rp.lmp_subver);
 	return 0;
@@ -1428,7 +1432,7 @@ int hci_read_local_version(int dd, struct hci_version *ver, int to)
 		return -1;
 	}
 
-	ver->err	= btohs(rp.err);
+	ver->manufacturer = btohs(rp.manufacturer);
 	ver->hci_ver      = rp.hci_ver;
 	ver->hci_rev      = btohs(rp.hci_rev);
 	ver->lmp_ver      = rp.lmp_ver;
